@@ -24,7 +24,6 @@ from ..kernel.hazards import (
     Drought,
     RiverineInundation,
     WaterRisk,
-    WaterStress,
     WaterTemperature,
 )
 from ..kernel.vulnerability_distrib import VulnerabilityDistrib
@@ -672,7 +671,7 @@ class ThermalPowerGenerationWaterTemperatureModel(VulnerabilityModelBase):
         return impact_distrib
 
 
-@applies_to_events([WaterStress])
+@applies_to_events([WaterRisk])
 @applies_to_assets([ThermalPowerGeneratingAsset])
 class ThermalPowerGenerationWaterStressModel(VulnerabilityModelBase):
     # Number of disrupted days per year
@@ -684,8 +683,6 @@ class ThermalPowerGenerationWaterStressModel(VulnerabilityModelBase):
 
         Args:
                 resource (str): embedded resource identifier used to infer vulnerability table.
-                correlation (float): correlation specifying the Gaussian copula which joins
-                                     the marginal distributions of water temperature and WBGT.
         """
         curve_set: VulnerabilityCurves = get_vulnerability_curves_from_resource(resource)
 
@@ -704,7 +701,7 @@ class ThermalPowerGenerationWaterStressModel(VulnerabilityModelBase):
         )
 
         # global circulation parameter 'model' is a hint; can be overriden by hazard model
-        super().__init__(indicator_id="water_stress", hazard_type=WaterStress, impact_type=impact_type)
+        super().__init__(indicator_id="water_stress", hazard_type=WaterRisk, impact_type=impact_type)
 
     def get_data_requests(
         self, asset: Asset, *, scenario: str, year: int
